@@ -1,6 +1,6 @@
 __all__ = ["VERSION", "get_version", "__version__"]
 
-VERSION = (1, 52, 4, "final", 0)
+VERSION = (1, 57, 2, "final", 0)
 
 
 def get_version():
@@ -24,5 +24,5 @@ __version__ = get_version()
 # This method cause the load of all installed apps, causing the circular dependency problem.
 # the following code force a "pre-load" of all installed app, solving the dependecy pb.
 # TODO: remove this by reworking ldt dependencies
-from django.db.models.loading import get_models
-_ = get_models()
+#from django.db.models.loading import get_models
+#_ = get_models()
